#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InvoiceAmountLimitInfo(object):

    def __init__(self):
        self._amount_limit = None
        self._invoice_kind = None
        self._month_amount_limit = None

    @property
    def amount_limit(self):
        return self._amount_limit

    @amount_limit.setter
    def amount_limit(self, value):
        self._amount_limit = value
    @property
    def invoice_kind(self):
        return self._invoice_kind

    @invoice_kind.setter
    def invoice_kind(self, value):
        self._invoice_kind = value
    @property
    def month_amount_limit(self):
        return self._month_amount_limit

    @month_amount_limit.setter
    def month_amount_limit(self, value):
        self._month_amount_limit = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount_limit:
            if hasattr(self.amount_limit, 'to_alipay_dict'):
                params['amount_limit'] = self.amount_limit.to_alipay_dict()
            else:
                params['amount_limit'] = self.amount_limit
        if self.invoice_kind:
            if hasattr(self.invoice_kind, 'to_alipay_dict'):
                params['invoice_kind'] = self.invoice_kind.to_alipay_dict()
            else:
                params['invoice_kind'] = self.invoice_kind
        if self.month_amount_limit:
            if hasattr(self.month_amount_limit, 'to_alipay_dict'):
                params['month_amount_limit'] = self.month_amount_limit.to_alipay_dict()
            else:
                params['month_amount_limit'] = self.month_amount_limit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvoiceAmountLimitInfo()
        if 'amount_limit' in d:
            o.amount_limit = d['amount_limit']
        if 'invoice_kind' in d:
            o.invoice_kind = d['invoice_kind']
        if 'month_amount_limit' in d:
            o.month_amount_limit = d['month_amount_limit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VoucherTimeRule import VoucherTimeRule
from alipay.aop.api.domain.VoucherSingleItemInfo import VoucherSingleItemInfo
from alipay.aop.api.domain.PromoInfo import PromoInfo
from alipay.aop.api.domain.VoucherTimeRule import VoucherTimeRule
from alipay.aop.api.domain.VoucherUseScopeInfo import VoucherUseScopeInfo


class VoucherTemplate(object):

    def __init__(self):
        self._available_time_rule = None
        self._date_type = None
        self._expire_time = None
        self._item_info = None
        self._promo_info = None
        self._promo_type = None
        self._send_time = None
        self._template_id = None
        self._threshold_amount = None
        self._unavailable_time_rule = None
        self._use_scope_info = None
        self._voucher_desc = None
        self._voucher_name = None
        self._voucher_quantity = None
        self._voucher_type = None

    @property
    def available_time_rule(self):
        return self._available_time_rule

    @available_time_rule.setter
    def available_time_rule(self, value):
        if isinstance(value, list):
            self._available_time_rule = list()
            for i in value:
                if isinstance(i, VoucherTimeRule):
                    self._available_time_rule.append(i)
                else:
                    self._available_time_rule.append(VoucherTimeRule.from_alipay_dict(i))
    @property
    def date_type(self):
        return self._date_type

    @date_type.setter
    def date_type(self, value):
        self._date_type = value
    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def item_info(self):
        return self._item_info

    @item_info.setter
    def item_info(self, value):
        if isinstance(value, VoucherSingleItemInfo):
            self._item_info = value
        else:
            self._item_info = VoucherSingleItemInfo.from_alipay_dict(value)
    @property
    def promo_info(self):
        return self._promo_info

    @promo_info.setter
    def promo_info(self, value):
        if isinstance(value, PromoInfo):
            self._promo_info = value
        else:
            self._promo_info = PromoInfo.from_alipay_dict(value)
    @property
    def promo_type(self):
        return self._promo_type

    @promo_type.setter
    def promo_type(self, value):
        self._promo_type = value
    @property
    def send_time(self):
        return self._send_time

    @send_time.setter
    def send_time(self, value):
        self._send_time = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def threshold_amount(self):
        return self._threshold_amount

    @threshold_amount.setter
    def threshold_amount(self, value):
        self._threshold_amount = value
    @property
    def unavailable_time_rule(self):
        return self._unavailable_time_rule

    @unavailable_time_rule.setter
    def unavailable_time_rule(self, value):
        if isinstance(value, list):
            self._unavailable_time_rule = list()
            for i in value:
                if isinstance(i, VoucherTimeRule):
                    self._unavailable_time_rule.append(i)
                else:
                    self._unavailable_time_rule.append(VoucherTimeRule.from_alipay_dict(i))
    @property
    def use_scope_info(self):
        return self._use_scope_info

    @use_scope_info.setter
    def use_scope_info(self, value):
        if isinstance(value, VoucherUseScopeInfo):
            self._use_scope_info = value
        else:
            self._use_scope_info = VoucherUseScopeInfo.from_alipay_dict(value)
    @property
    def voucher_desc(self):
        return self._voucher_desc

    @voucher_desc.setter
    def voucher_desc(self, value):
        self._voucher_desc = value
    @property
    def voucher_name(self):
        return self._voucher_name

    @voucher_name.setter
    def voucher_name(self, value):
        self._voucher_name = value
    @property
    def voucher_quantity(self):
        return self._voucher_quantity

    @voucher_quantity.setter
    def voucher_quantity(self, value):
        self._voucher_quantity = value
    @property
    def voucher_type(self):
        return self._voucher_type

    @voucher_type.setter
    def voucher_type(self, value):
        self._voucher_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.available_time_rule:
            if isinstance(self.available_time_rule, list):
                for i in range(0, len(self.available_time_rule)):
                    element = self.available_time_rule[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.available_time_rule[i] = element.to_alipay_dict()
            if hasattr(self.available_time_rule, 'to_alipay_dict'):
                params['available_time_rule'] = self.available_time_rule.to_alipay_dict()
            else:
                params['available_time_rule'] = self.available_time_rule
        if self.date_type:
            if hasattr(self.date_type, 'to_alipay_dict'):
                params['date_type'] = self.date_type.to_alipay_dict()
            else:
                params['date_type'] = self.date_type
        if self.expire_time:
            if hasattr(self.expire_time, 'to_alipay_dict'):
                params['expire_time'] = self.expire_time.to_alipay_dict()
            else:
                params['expire_time'] = self.expire_time
        if self.item_info:
            if hasattr(self.item_info, 'to_alipay_dict'):
                params['item_info'] = self.item_info.to_alipay_dict()
            else:
                params['item_info'] = self.item_info
        if self.promo_info:
            if hasattr(self.promo_info, 'to_alipay_dict'):
                params['promo_info'] = self.promo_info.to_alipay_dict()
            else:
                params['promo_info'] = self.promo_info
        if self.promo_type:
            if hasattr(self.promo_type, 'to_alipay_dict'):
                params['promo_type'] = self.promo_type.to_alipay_dict()
            else:
                params['promo_type'] = self.promo_type
        if self.send_time:
            if hasattr(self.send_time, 'to_alipay_dict'):
                params['send_time'] = self.send_time.to_alipay_dict()
            else:
                params['send_time'] = self.send_time
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.threshold_amount:
            if hasattr(self.threshold_amount, 'to_alipay_dict'):
                params['threshold_amount'] = self.threshold_amount.to_alipay_dict()
            else:
                params['threshold_amount'] = self.threshold_amount
        if self.unavailable_time_rule:
            if isinstance(self.unavailable_time_rule, list):
                for i in range(0, len(self.unavailable_time_rule)):
                    element = self.unavailable_time_rule[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.unavailable_time_rule[i] = element.to_alipay_dict()
            if hasattr(self.unavailable_time_rule, 'to_alipay_dict'):
                params['unavailable_time_rule'] = self.unavailable_time_rule.to_alipay_dict()
            else:
                params['unavailable_time_rule'] = self.unavailable_time_rule
        if self.use_scope_info:
            if hasattr(self.use_scope_info, 'to_alipay_dict'):
                params['use_scope_info'] = self.use_scope_info.to_alipay_dict()
            else:
                params['use_scope_info'] = self.use_scope_info
        if self.voucher_desc:
            if hasattr(self.voucher_desc, 'to_alipay_dict'):
                params['voucher_desc'] = self.voucher_desc.to_alipay_dict()
            else:
                params['voucher_desc'] = self.voucher_desc
        if self.voucher_name:
            if hasattr(self.voucher_name, 'to_alipay_dict'):
                params['voucher_name'] = self.voucher_name.to_alipay_dict()
            else:
                params['voucher_name'] = self.voucher_name
        if self.voucher_quantity:
            if hasattr(self.voucher_quantity, 'to_alipay_dict'):
                params['voucher_quantity'] = self.voucher_quantity.to_alipay_dict()
            else:
                params['voucher_quantity'] = self.voucher_quantity
        if self.voucher_type:
            if hasattr(self.voucher_type, 'to_alipay_dict'):
                params['voucher_type'] = self.voucher_type.to_alipay_dict()
            else:
                params['voucher_type'] = self.voucher_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherTemplate()
        if 'available_time_rule' in d:
            o.available_time_rule = d['available_time_rule']
        if 'date_type' in d:
            o.date_type = d['date_type']
        if 'expire_time' in d:
            o.expire_time = d['expire_time']
        if 'item_info' in d:
            o.item_info = d['item_info']
        if 'promo_info' in d:
            o.promo_info = d['promo_info']
        if 'promo_type' in d:
            o.promo_type = d['promo_type']
        if 'send_time' in d:
            o.send_time = d['send_time']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'threshold_amount' in d:
            o.threshold_amount = d['threshold_amount']
        if 'unavailable_time_rule' in d:
            o.unavailable_time_rule = d['unavailable_time_rule']
        if 'use_scope_info' in d:
            o.use_scope_info = d['use_scope_info']
        if 'voucher_desc' in d:
            o.voucher_desc = d['voucher_desc']
        if 'voucher_name' in d:
            o.voucher_name = d['voucher_name']
        if 'voucher_quantity' in d:
            o.voucher_quantity = d['voucher_quantity']
        if 'voucher_type' in d:
            o.voucher_type = d['voucher_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.FinEquityInfo import FinEquityInfo


class AntfortuneMarketingUserThirdpartequityQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntfortuneMarketingUserThirdpartequityQueryResponse, self).__init__()
        self._equity_info = None
        self._should_retry = None

    @property
    def equity_info(self):
        return self._equity_info

    @equity_info.setter
    def equity_info(self, value):
        if isinstance(value, list):
            self._equity_info = list()
            for i in value:
                if isinstance(i, FinEquityInfo):
                    self._equity_info.append(i)
                else:
                    self._equity_info.append(FinEquityInfo.from_alipay_dict(i))
    @property
    def should_retry(self):
        return self._should_retry

    @should_retry.setter
    def should_retry(self, value):
        self._should_retry = value

    def parse_response_content(self, response_content):
        response = super(AntfortuneMarketingUserThirdpartequityQueryResponse, self).parse_response_content(response_content)
        if 'equity_info' in response:
            self.equity_info = response['equity_info']
        if 'should_retry' in response:
            self.should_retry = response['should_retry']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiContentContentinfoModifyResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiContentContentinfoModifyResponse, self).__init__()
        self._data = None
        self._trace_id = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value

    def parse_response_content(self, response_content):
        response = super(KoubeiContentContentinfoModifyResponse, self).parse_response_content(response_content)
        if 'data' in response:
            self.data = response['data']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringDishConditionBatchqueryModel(object):

    def __init__(self):
        self._catetory_big_id = None
        self._catetory_small_id = None
        self._dish_id = None
        self._dish_name = None
        self._merchant_id = None
        self._page_no = None
        self._page_size = None
        self._shop_id = None

    @property
    def catetory_big_id(self):
        return self._catetory_big_id

    @catetory_big_id.setter
    def catetory_big_id(self, value):
        self._catetory_big_id = value
    @property
    def catetory_small_id(self):
        return self._catetory_small_id

    @catetory_small_id.setter
    def catetory_small_id(self, value):
        self._catetory_small_id = value
    @property
    def dish_id(self):
        return self._dish_id

    @dish_id.setter
    def dish_id(self, value):
        self._dish_id = value
    @property
    def dish_name(self):
        return self._dish_name

    @dish_name.setter
    def dish_name(self, value):
        self._dish_name = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.catetory_big_id:
            if hasattr(self.catetory_big_id, 'to_alipay_dict'):
                params['catetory_big_id'] = self.catetory_big_id.to_alipay_dict()
            else:
                params['catetory_big_id'] = self.catetory_big_id
        if self.catetory_small_id:
            if hasattr(self.catetory_small_id, 'to_alipay_dict'):
                params['catetory_small_id'] = self.catetory_small_id.to_alipay_dict()
            else:
                params['catetory_small_id'] = self.catetory_small_id
        if self.dish_id:
            if hasattr(self.dish_id, 'to_alipay_dict'):
                params['dish_id'] = self.dish_id.to_alipay_dict()
            else:
                params['dish_id'] = self.dish_id
        if self.dish_name:
            if hasattr(self.dish_name, 'to_alipay_dict'):
                params['dish_name'] = self.dish_name.to_alipay_dict()
            else:
                params['dish_name'] = self.dish_name
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishConditionBatchqueryModel()
        if 'catetory_big_id' in d:
            o.catetory_big_id = d['catetory_big_id']
        if 'catetory_small_id' in d:
            o.catetory_small_id = d['catetory_small_id']
        if 'dish_id' in d:
            o.dish_id = d['dish_id']
        if 'dish_name' in d:
            o.dish_name = d['dish_name']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BusinessPermission import BusinessPermission
from alipay.aop.api.domain.BusinessPermission import BusinessPermission


class KoubeiMerchantRolePermissionCreateModel(object):

    def __init__(self):
        self._auth_code = None
        self._permissions_to_add = None
        self._permissions_to_delete = None
        self._principal_id = None
        self._principal_type = None

    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def permissions_to_add(self):
        return self._permissions_to_add

    @permissions_to_add.setter
    def permissions_to_add(self, value):
        if isinstance(value, list):
            self._permissions_to_add = list()
            for i in value:
                if isinstance(i, BusinessPermission):
                    self._permissions_to_add.append(i)
                else:
                    self._permissions_to_add.append(BusinessPermission.from_alipay_dict(i))
    @property
    def permissions_to_delete(self):
        return self._permissions_to_delete

    @permissions_to_delete.setter
    def permissions_to_delete(self, value):
        if isinstance(value, list):
            self._permissions_to_delete = list()
            for i in value:
                if isinstance(i, BusinessPermission):
                    self._permissions_to_delete.append(i)
                else:
                    self._permissions_to_delete.append(BusinessPermission.from_alipay_dict(i))
    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def principal_type(self):
        return self._principal_type

    @principal_type.setter
    def principal_type(self, value):
        self._principal_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_code:
            if hasattr(self.auth_code, 'to_alipay_dict'):
                params['auth_code'] = self.auth_code.to_alipay_dict()
            else:
                params['auth_code'] = self.auth_code
        if self.permissions_to_add:
            if isinstance(self.permissions_to_add, list):
                for i in range(0, len(self.permissions_to_add)):
                    element = self.permissions_to_add[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.permissions_to_add[i] = element.to_alipay_dict()
            if hasattr(self.permissions_to_add, 'to_alipay_dict'):
                params['permissions_to_add'] = self.permissions_to_add.to_alipay_dict()
            else:
                params['permissions_to_add'] = self.permissions_to_add
        if self.permissions_to_delete:
            if isinstance(self.permissions_to_delete, list):
                for i in range(0, len(self.permissions_to_delete)):
                    element = self.permissions_to_delete[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.permissions_to_delete[i] = element.to_alipay_dict()
            if hasattr(self.permissions_to_delete, 'to_alipay_dict'):
                params['permissions_to_delete'] = self.permissions_to_delete.to_alipay_dict()
            else:
                params['permissions_to_delete'] = self.permissions_to_delete
        if self.principal_id:
            if hasattr(self.principal_id, 'to_alipay_dict'):
                params['principal_id'] = self.principal_id.to_alipay_dict()
            else:
                params['principal_id'] = self.principal_id
        if self.principal_type:
            if hasattr(self.principal_type, 'to_alipay_dict'):
                params['principal_type'] = self.principal_type.to_alipay_dict()
            else:
                params['principal_type'] = self.principal_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMerchantRolePermissionCreateModel()
        if 'auth_code' in d:
            o.auth_code = d['auth_code']
        if 'permissions_to_add' in d:
            o.permissions_to_add = d['permissions_to_add']
        if 'permissions_to_delete' in d:
            o.permissions_to_delete = d['permissions_to_delete']
        if 'principal_id' in d:
            o.principal_id = d['principal_id']
        if 'principal_type' in d:
            o.principal_type = d['principal_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CreditPayChargePricingVO import CreditPayChargePricingVO
from alipay.aop.api.domain.CreditPayClauseVO import CreditPayClauseVO
from alipay.aop.api.domain.CreditPayIntPricingVO import CreditPayIntPricingVO


class CreditPayCompensateDetailVO(object):

    def __init__(self):
        self._charge_pricing_list = None
        self._clauses = None
        self._instal_itrv = None
        self._instal_type = None
        self._int_pricing = None

    @property
    def charge_pricing_list(self):
        return self._charge_pricing_list

    @charge_pricing_list.setter
    def charge_pricing_list(self, value):
        if isinstance(value, list):
            self._charge_pricing_list = list()
            for i in value:
                if isinstance(i, CreditPayChargePricingVO):
                    self._charge_pricing_list.append(i)
                else:
                    self._charge_pricing_list.append(CreditPayChargePricingVO.from_alipay_dict(i))
    @property
    def clauses(self):
        return self._clauses

    @clauses.setter
    def clauses(self, value):
        if isinstance(value, list):
            self._clauses = list()
            for i in value:
                if isinstance(i, CreditPayClauseVO):
                    self._clauses.append(i)
                else:
                    self._clauses.append(CreditPayClauseVO.from_alipay_dict(i))
    @property
    def instal_itrv(self):
        return self._instal_itrv

    @instal_itrv.setter
    def instal_itrv(self, value):
        self._instal_itrv = value
    @property
    def instal_type(self):
        return self._instal_type

    @instal_type.setter
    def instal_type(self, value):
        self._instal_type = value
    @property
    def int_pricing(self):
        return self._int_pricing

    @int_pricing.setter
    def int_pricing(self, value):
        if isinstance(value, CreditPayIntPricingVO):
            self._int_pricing = value
        else:
            self._int_pricing = CreditPayIntPricingVO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.charge_pricing_list:
            if isinstance(self.charge_pricing_list, list):
                for i in range(0, len(self.charge_pricing_list)):
                    element = self.charge_pricing_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.charge_pricing_list[i] = element.to_alipay_dict()
            if hasattr(self.charge_pricing_list, 'to_alipay_dict'):
                params['charge_pricing_list'] = self.charge_pricing_list.to_alipay_dict()
            else:
                params['charge_pricing_list'] = self.charge_pricing_list
        if self.clauses:
            if isinstance(self.clauses, list):
                for i in range(0, len(self.clauses)):
                    element = self.clauses[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.clauses[i] = element.to_alipay_dict()
            if hasattr(self.clauses, 'to_alipay_dict'):
                params['clauses'] = self.clauses.to_alipay_dict()
            else:
                params['clauses'] = self.clauses
        if self.instal_itrv:
            if hasattr(self.instal_itrv, 'to_alipay_dict'):
                params['instal_itrv'] = self.instal_itrv.to_alipay_dict()
            else:
                params['instal_itrv'] = self.instal_itrv
        if self.instal_type:
            if hasattr(self.instal_type, 'to_alipay_dict'):
                params['instal_type'] = self.instal_type.to_alipay_dict()
            else:
                params['instal_type'] = self.instal_type
        if self.int_pricing:
            if hasattr(self.int_pricing, 'to_alipay_dict'):
                params['int_pricing'] = self.int_pricing.to_alipay_dict()
            else:
                params['int_pricing'] = self.int_pricing
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CreditPayCompensateDetailVO()
        if 'charge_pricing_list' in d:
            o.charge_pricing_list = d['charge_pricing_list']
        if 'clauses' in d:
            o.clauses = d['clauses']
        if 'instal_itrv' in d:
            o.instal_itrv = d['instal_itrv']
        if 'instal_type' in d:
            o.instal_type = d['instal_type']
        if 'int_pricing' in d:
            o.int_pricing = d['int_pricing']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MdCodeInfoDTO(object):

    def __init__(self):
        self._code_status = None
        self._code_value = None
        self._expire_time = None
        self._time_stamp = None

    @property
    def code_status(self):
        return self._code_status

    @code_status.setter
    def code_status(self, value):
        self._code_status = value
    @property
    def code_value(self):
        return self._code_value

    @code_value.setter
    def code_value(self, value):
        self._code_value = value
    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def time_stamp(self):
        return self._time_stamp

    @time_stamp.setter
    def time_stamp(self, value):
        self._time_stamp = value


    def to_alipay_dict(self):
        params = dict()
        if self.code_status:
            if hasattr(self.code_status, 'to_alipay_dict'):
                params['code_status'] = self.code_status.to_alipay_dict()
            else:
                params['code_status'] = self.code_status
        if self.code_value:
            if hasattr(self.code_value, 'to_alipay_dict'):
                params['code_value'] = self.code_value.to_alipay_dict()
            else:
                params['code_value'] = self.code_value
        if self.expire_time:
            if hasattr(self.expire_time, 'to_alipay_dict'):
                params['expire_time'] = self.expire_time.to_alipay_dict()
            else:
                params['expire_time'] = self.expire_time
        if self.time_stamp:
            if hasattr(self.time_stamp, 'to_alipay_dict'):
                params['time_stamp'] = self.time_stamp.to_alipay_dict()
            else:
                params['time_stamp'] = self.time_stamp
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MdCodeInfoDTO()
        if 'code_status' in d:
            o.code_status = d['code_status']
        if 'code_value' in d:
            o.code_value = d['code_value']
        if 'expire_time' in d:
            o.expire_time = d['expire_time']
        if 'time_stamp' in d:
            o.time_stamp = d['time_stamp']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaRiskDetail(object):

    def __init__(self):
        self._data_type = None
        self._extendinfo = None
        self._risk_code = None
        self._risk_type = None
        self._settlement = None
        self._statement = None
        self._status = None
        self._type = None
        self._update = None

    @property
    def data_type(self):
        return self._data_type

    @data_type.setter
    def data_type(self, value):
        self._data_type = value
    @property
    def extendinfo(self):
        return self._extendinfo

    @extendinfo.setter
    def extendinfo(self, value):
        self._extendinfo = value
    @property
    def risk_code(self):
        return self._risk_code

    @risk_code.setter
    def risk_code(self, value):
        self._risk_code = value
    @property
    def risk_type(self):
        return self._risk_type

    @risk_type.setter
    def risk_type(self, value):
        self._risk_type = value
    @property
    def settlement(self):
        return self._settlement

    @settlement.setter
    def settlement(self, value):
        self._settlement = value
    @property
    def statement(self):
        return self._statement

    @statement.setter
    def statement(self, value):
        self._statement = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def update(self):
        return self._update

    @update.setter
    def update(self, value):
        self._update = value


    def to_alipay_dict(self):
        params = dict()
        if self.data_type:
            if hasattr(self.data_type, 'to_alipay_dict'):
                params['data_type'] = self.data_type.to_alipay_dict()
            else:
                params['data_type'] = self.data_type
        if self.extendinfo:
            if hasattr(self.extendinfo, 'to_alipay_dict'):
                params['extendinfo'] = self.extendinfo.to_alipay_dict()
            else:
                params['extendinfo'] = self.extendinfo
        if self.risk_code:
            if hasattr(self.risk_code, 'to_alipay_dict'):
                params['risk_code'] = self.risk_code.to_alipay_dict()
            else:
                params['risk_code'] = self.risk_code
        if self.risk_type:
            if hasattr(self.risk_type, 'to_alipay_dict'):
                params['risk_type'] = self.risk_type.to_alipay_dict()
            else:
                params['risk_type'] = self.risk_type
        if self.settlement:
            if hasattr(self.settlement, 'to_alipay_dict'):
                params['settlement'] = self.settlement.to_alipay_dict()
            else:
                params['settlement'] = self.settlement
        if self.statement:
            if hasattr(self.statement, 'to_alipay_dict'):
                params['statement'] = self.statement.to_alipay_dict()
            else:
                params['statement'] = self.statement
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.update:
            if hasattr(self.update, 'to_alipay_dict'):
                params['update'] = self.update.to_alipay_dict()
            else:
                params['update'] = self.update
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaRiskDetail()
        if 'data_type' in d:
            o.data_type = d['data_type']
        if 'extendinfo' in d:
            o.extendinfo = d['extendinfo']
        if 'risk_code' in d:
            o.risk_code = d['risk_code']
        if 'risk_type' in d:
            o.risk_type = d['risk_type']
        if 'settlement' in d:
            o.settlement = d['settlement']
        if 'statement' in d:
            o.statement = d['statement']
        if 'status' in d:
            o.status = d['status']
        if 'type' in d:
            o.type = d['type']
        if 'update' in d:
            o.update = d['update']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppAppcontentItemQueryModel(object):

    def __init__(self):
        self._alipay_app_id = None
        self._item_status = None
        self._item_title = None
        self._page_num = None
        self._page_size = None
        self._pid = None

    @property
    def alipay_app_id(self):
        return self._alipay_app_id

    @alipay_app_id.setter
    def alipay_app_id(self, value):
        self._alipay_app_id = value
    @property
    def item_status(self):
        return self._item_status

    @item_status.setter
    def item_status(self, value):
        self._item_status = value
    @property
    def item_title(self):
        return self._item_title

    @item_title.setter
    def item_title(self, value):
        self._item_title = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_app_id:
            if hasattr(self.alipay_app_id, 'to_alipay_dict'):
                params['alipay_app_id'] = self.alipay_app_id.to_alipay_dict()
            else:
                params['alipay_app_id'] = self.alipay_app_id
        if self.item_status:
            if hasattr(self.item_status, 'to_alipay_dict'):
                params['item_status'] = self.item_status.to_alipay_dict()
            else:
                params['item_status'] = self.item_status
        if self.item_title:
            if hasattr(self.item_title, 'to_alipay_dict'):
                params['item_title'] = self.item_title.to_alipay_dict()
            else:
                params['item_title'] = self.item_title
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppAppcontentItemQueryModel()
        if 'alipay_app_id' in d:
            o.alipay_app_id = d['alipay_app_id']
        if 'item_status' in d:
            o.item_status = d['item_status']
        if 'item_title' in d:
            o.item_title = d['item_title']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'pid' in d:
            o.pid = d['pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringPosDishcateTransferModel(object):

    def __init__(self):
        self._cate_id = None
        self._cook_id = None
        self._dish_ids = None
        self._shop_id = None

    @property
    def cate_id(self):
        return self._cate_id

    @cate_id.setter
    def cate_id(self, value):
        self._cate_id = value
    @property
    def cook_id(self):
        return self._cook_id

    @cook_id.setter
    def cook_id(self, value):
        self._cook_id = value
    @property
    def dish_ids(self):
        return self._dish_ids

    @dish_ids.setter
    def dish_ids(self, value):
        if isinstance(value, list):
            self._dish_ids = list()
            for i in value:
                self._dish_ids.append(i)
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.cate_id:
            if hasattr(self.cate_id, 'to_alipay_dict'):
                params['cate_id'] = self.cate_id.to_alipay_dict()
            else:
                params['cate_id'] = self.cate_id
        if self.cook_id:
            if hasattr(self.cook_id, 'to_alipay_dict'):
                params['cook_id'] = self.cook_id.to_alipay_dict()
            else:
                params['cook_id'] = self.cook_id
        if self.dish_ids:
            if isinstance(self.dish_ids, list):
                for i in range(0, len(self.dish_ids)):
                    element = self.dish_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dish_ids[i] = element.to_alipay_dict()
            if hasattr(self.dish_ids, 'to_alipay_dict'):
                params['dish_ids'] = self.dish_ids.to_alipay_dict()
            else:
                params['dish_ids'] = self.dish_ids
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringPosDishcateTransferModel()
        if 'cate_id' in d:
            o.cate_id = d['cate_id']
        if 'cook_id' in d:
            o.cook_id = d['cook_id']
        if 'dish_ids' in d:
            o.dish_ids = d['dish_ids']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsMarketingGiftQueryModel(object):

    def __init__(self):
        self._channel = None
        self._entrance = None
        self._gift_prod_code = None
        self._insured_open_id = None
        self._insured_user_id = None
        self._open_id = None
        self._relation_to_apply = None
        self._right_no_list = None
        self._source = None
        self._user_id = None

    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def entrance(self):
        return self._entrance

    @entrance.setter
    def entrance(self, value):
        self._entrance = value
    @property
    def gift_prod_code(self):
        return self._gift_prod_code

    @gift_prod_code.setter
    def gift_prod_code(self, value):
        self._gift_prod_code = value
    @property
    def insured_open_id(self):
        return self._insured_open_id

    @insured_open_id.setter
    def insured_open_id(self, value):
        self._insured_open_id = value
    @property
    def insured_user_id(self):
        return self._insured_user_id

    @insured_user_id.setter
    def insured_user_id(self, value):
        self._insured_user_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def relation_to_apply(self):
        return self._relation_to_apply

    @relation_to_apply.setter
    def relation_to_apply(self, value):
        self._relation_to_apply = value
    @property
    def right_no_list(self):
        return self._right_no_list

    @right_no_list.setter
    def right_no_list(self, value):
        if isinstance(value, list):
            self._right_no_list = list()
            for i in value:
                self._right_no_list.append(i)
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.entrance:
            if hasattr(self.entrance, 'to_alipay_dict'):
                params['entrance'] = self.entrance.to_alipay_dict()
            else:
                params['entrance'] = self.entrance
        if self.gift_prod_code:
            if hasattr(self.gift_prod_code, 'to_alipay_dict'):
                params['gift_prod_code'] = self.gift_prod_code.to_alipay_dict()
            else:
                params['gift_prod_code'] = self.gift_prod_code
        if self.insured_open_id:
            if hasattr(self.insured_open_id, 'to_alipay_dict'):
                params['insured_open_id'] = self.insured_open_id.to_alipay_dict()
            else:
                params['insured_open_id'] = self.insured_open_id
        if self.insured_user_id:
            if hasattr(self.insured_user_id, 'to_alipay_dict'):
                params['insured_user_id'] = self.insured_user_id.to_alipay_dict()
            else:
                params['insured_user_id'] = self.insured_user_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.relation_to_apply:
            if hasattr(self.relation_to_apply, 'to_alipay_dict'):
                params['relation_to_apply'] = self.relation_to_apply.to_alipay_dict()
            else:
                params['relation_to_apply'] = self.relation_to_apply
        if self.right_no_list:
            if isinstance(self.right_no_list, list):
                for i in range(0, len(self.right_no_list)):
                    element = self.right_no_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.right_no_list[i] = element.to_alipay_dict()
            if hasattr(self.right_no_list, 'to_alipay_dict'):
                params['right_no_list'] = self.right_no_list.to_alipay_dict()
            else:
                params['right_no_list'] = self.right_no_list
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsMarketingGiftQueryModel()
        if 'channel' in d:
            o.channel = d['channel']
        if 'entrance' in d:
            o.entrance = d['entrance']
        if 'gift_prod_code' in d:
            o.gift_prod_code = d['gift_prod_code']
        if 'insured_open_id' in d:
            o.insured_open_id = d['insured_open_id']
        if 'insured_user_id' in d:
            o.insured_user_id = d['insured_user_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'relation_to_apply' in d:
            o.relation_to_apply = d['relation_to_apply']
        if 'right_no_list' in d:
            o.right_no_list = d['right_no_list']
        if 'source' in d:
            o.source = d['source']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayDataBillAccountdailyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataBillAccountdailyQueryResponse, self).__init__()
        self._deposit_amount = None
        self._trans_in_amount = None
        self._trans_out_amount = None
        self._withdraw_amount = None

    @property
    def deposit_amount(self):
        return self._deposit_amount

    @deposit_amount.setter
    def deposit_amount(self, value):
        self._deposit_amount = value
    @property
    def trans_in_amount(self):
        return self._trans_in_amount

    @trans_in_amount.setter
    def trans_in_amount(self, value):
        self._trans_in_amount = value
    @property
    def trans_out_amount(self):
        return self._trans_out_amount

    @trans_out_amount.setter
    def trans_out_amount(self, value):
        self._trans_out_amount = value
    @property
    def withdraw_amount(self):
        return self._withdraw_amount

    @withdraw_amount.setter
    def withdraw_amount(self, value):
        self._withdraw_amount = value

    def parse_response_content(self, response_content):
        response = super(AlipayDataBillAccountdailyQueryResponse, self).parse_response_content(response_content)
        if 'deposit_amount' in response:
            self.deposit_amount = response['deposit_amount']
        if 'trans_in_amount' in response:
            self.trans_in_amount = response['trans_in_amount']
        if 'trans_out_amount' in response:
            self.trans_out_amount = response['trans_out_amount']
        if 'withdraw_amount' in response:
            self.withdraw_amount = response['withdraw_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PromotionRelationDTO import PromotionRelationDTO


class AlipayOpenSpIsvRelationQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenSpIsvRelationQueryResponse, self).__init__()
        self._current_page = None
        self._page_size = None
        self._promotion_relations = None
        self._total_size = None

    @property
    def current_page(self):
        return self._current_page

    @current_page.setter
    def current_page(self, value):
        self._current_page = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def promotion_relations(self):
        return self._promotion_relations

    @promotion_relations.setter
    def promotion_relations(self, value):
        if isinstance(value, list):
            self._promotion_relations = list()
            for i in value:
                if isinstance(i, PromotionRelationDTO):
                    self._promotion_relations.append(i)
                else:
                    self._promotion_relations.append(PromotionRelationDTO.from_alipay_dict(i))
    @property
    def total_size(self):
        return self._total_size

    @total_size.setter
    def total_size(self, value):
        self._total_size = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenSpIsvRelationQueryResponse, self).parse_response_content(response_content)
        if 'current_page' in response:
            self.current_page = response['current_page']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'promotion_relations' in response:
            self.promotion_relations = response['promotion_relations']
        if 'total_size' in response:
            self.total_size = response['total_size']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCustomerContractInitializeModel(object):

    def __init__(self):
        self._contract_file = None
        self._contract_name = None
        self._product_code = None

    @property
    def contract_file(self):
        return self._contract_file

    @contract_file.setter
    def contract_file(self, value):
        self._contract_file = value
    @property
    def contract_name(self):
        return self._contract_name

    @contract_name.setter
    def contract_name(self, value):
        self._contract_name = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.contract_file:
            if hasattr(self.contract_file, 'to_alipay_dict'):
                params['contract_file'] = self.contract_file.to_alipay_dict()
            else:
                params['contract_file'] = self.contract_file
        if self.contract_name:
            if hasattr(self.contract_name, 'to_alipay_dict'):
                params['contract_name'] = self.contract_name.to_alipay_dict()
            else:
                params['contract_name'] = self.contract_name
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCustomerContractInitializeModel()
        if 'contract_file' in d:
            o.contract_file = d['contract_file']
        if 'contract_name' in d:
            o.contract_name = d['contract_name']
        if 'product_code' in d:
            o.product_code = d['product_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoCplifeBasicserviceModifyModel(object):

    def __init__(self):
        self._account = None
        self._account_type = None
        self._community_id = None
        self._external_invoke_address = None
        self._service_expires = None
        self._service_type = None
        self._status = None

    @property
    def account(self):
        return self._account

    @account.setter
    def account(self, value):
        self._account = value
    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def community_id(self):
        return self._community_id

    @community_id.setter
    def community_id(self, value):
        self._community_id = value
    @property
    def external_invoke_address(self):
        return self._external_invoke_address

    @external_invoke_address.setter
    def external_invoke_address(self, value):
        self._external_invoke_address = value
    @property
    def service_expires(self):
        return self._service_expires

    @service_expires.setter
    def service_expires(self, value):
        self._service_expires = value
    @property
    def service_type(self):
        return self._service_type

    @service_type.setter
    def service_type(self, value):
        self._service_type = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.account:
            if hasattr(self.account, 'to_alipay_dict'):
                params['account'] = self.account.to_alipay_dict()
            else:
                params['account'] = self.account
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        if self.community_id:
            if hasattr(self.community_id, 'to_alipay_dict'):
                params['community_id'] = self.community_id.to_alipay_dict()
            else:
                params['community_id'] = self.community_id
        if self.external_invoke_address:
            if hasattr(self.external_invoke_address, 'to_alipay_dict'):
                params['external_invoke_address'] = self.external_invoke_address.to_alipay_dict()
            else:
                params['external_invoke_address'] = self.external_invoke_address
        if self.service_expires:
            if hasattr(self.service_expires, 'to_alipay_dict'):
                params['service_expires'] = self.service_expires.to_alipay_dict()
            else:
                params['service_expires'] = self.service_expires
        if self.service_type:
            if hasattr(self.service_type, 'to_alipay_dict'):
                params['service_type'] = self.service_type.to_alipay_dict()
            else:
                params['service_type'] = self.service_type
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoCplifeBasicserviceModifyModel()
        if 'account' in d:
            o.account = d['account']
        if 'account_type' in d:
            o.account_type = d['account_type']
        if 'community_id' in d:
            o.community_id = d['community_id']
        if 'external_invoke_address' in d:
            o.external_invoke_address = d['external_invoke_address']
        if 'service_expires' in d:
            o.service_expires = d['service_expires']
        if 'service_type' in d:
            o.service_type = d['service_type']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySocialBaseChatMsgSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialBaseChatMsgSendResponse, self).__init__()
        self._msg_index = None

    @property
    def msg_index(self):
        return self._msg_index

    @msg_index.setter
    def msg_index(self, value):
        self._msg_index = value

    def parse_response_content(self, response_content):
        response = super(AlipaySocialBaseChatMsgSendResponse, self).parse_response_content(response_content)
        if 'msg_index' in response:
            self.msg_index = response['msg_index']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CommonPrizeVo(object):

    def __init__(self):
        self._prize_desc = None
        self._prize_image_url = None
        self._prize_name = None
        self._prize_num = None

    @property
    def prize_desc(self):
        return self._prize_desc

    @prize_desc.setter
    def prize_desc(self, value):
        self._prize_desc = value
    @property
    def prize_image_url(self):
        return self._prize_image_url

    @prize_image_url.setter
    def prize_image_url(self, value):
        self._prize_image_url = value
    @property
    def prize_name(self):
        return self._prize_name

    @prize_name.setter
    def prize_name(self, value):
        self._prize_name = value
    @property
    def prize_num(self):
        return self._prize_num

    @prize_num.setter
    def prize_num(self, value):
        self._prize_num = value


    def to_alipay_dict(self):
        params = dict()
        if self.prize_desc:
            if hasattr(self.prize_desc, 'to_alipay_dict'):
                params['prize_desc'] = self.prize_desc.to_alipay_dict()
            else:
                params['prize_desc'] = self.prize_desc
        if self.prize_image_url:
            if hasattr(self.prize_image_url, 'to_alipay_dict'):
                params['prize_image_url'] = self.prize_image_url.to_alipay_dict()
            else:
                params['prize_image_url'] = self.prize_image_url
        if self.prize_name:
            if hasattr(self.prize_name, 'to_alipay_dict'):
                params['prize_name'] = self.prize_name.to_alipay_dict()
            else:
                params['prize_name'] = self.prize_name
        if self.prize_num:
            if hasattr(self.prize_num, 'to_alipay_dict'):
                params['prize_num'] = self.prize_num.to_alipay_dict()
            else:
                params['prize_num'] = self.prize_num
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CommonPrizeVo()
        if 'prize_desc' in d:
            o.prize_desc = d['prize_desc']
        if 'prize_image_url' in d:
            o.prize_image_url = d['prize_image_url']
        if 'prize_name' in d:
            o.prize_name = d['prize_name']
        if 'prize_num' in d:
            o.prize_num = d['prize_num']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntfortuneStockQualifiedInvestorApplyModel(object):

    def __init__(self):
        self._id_number_encrypt = None

    @property
    def id_number_encrypt(self):
        return self._id_number_encrypt

    @id_number_encrypt.setter
    def id_number_encrypt(self, value):
        self._id_number_encrypt = value


    def to_alipay_dict(self):
        params = dict()
        if self.id_number_encrypt:
            if hasattr(self.id_number_encrypt, 'to_alipay_dict'):
                params['id_number_encrypt'] = self.id_number_encrypt.to_alipay_dict()
            else:
                params['id_number_encrypt'] = self.id_number_encrypt
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntfortuneStockQualifiedInvestorApplyModel()
        if 'id_number_encrypt' in d:
            o.id_number_encrypt = d['id_number_encrypt']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenPublicAdvertCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenPublicAdvertCreateResponse, self).__init__()
        self._advert_group = None
        self._advert_id = None

    @property
    def advert_group(self):
        return self._advert_group

    @advert_group.setter
    def advert_group(self, value):
        self._advert_group = value
    @property
    def advert_id(self):
        return self._advert_id

    @advert_id.setter
    def advert_id(self, value):
        self._advert_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenPublicAdvertCreateResponse, self).parse_response_content(response_content)
        if 'advert_group' in response:
            self.advert_group = response['advert_group']
        if 'advert_id' in response:
            self.advert_id = response['advert_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class QueueInfo(object):

    def __init__(self):
        self._current_num = None
        self._dining_num = None
        self._queue_num = None
        self._still_wait_time = None
        self._table_type = None
        self._wait_num = None
        self._waiting_time = None

    @property
    def current_num(self):
        return self._current_num

    @current_num.setter
    def current_num(self, value):
        self._current_num = value
    @property
    def dining_num(self):
        return self._dining_num

    @dining_num.setter
    def dining_num(self, value):
        self._dining_num = value
    @property
    def queue_num(self):
        return self._queue_num

    @queue_num.setter
    def queue_num(self, value):
        self._queue_num = value
    @property
    def still_wait_time(self):
        return self._still_wait_time

    @still_wait_time.setter
    def still_wait_time(self, value):
        self._still_wait_time = value
    @property
    def table_type(self):
        return self._table_type

    @table_type.setter
    def table_type(self, value):
        self._table_type = value
    @property
    def wait_num(self):
        return self._wait_num

    @wait_num.setter
    def wait_num(self, value):
        self._wait_num = value
    @property
    def waiting_time(self):
        return self._waiting_time

    @waiting_time.setter
    def waiting_time(self, value):
        self._waiting_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.current_num:
            if hasattr(self.current_num, 'to_alipay_dict'):
                params['current_num'] = self.current_num.to_alipay_dict()
            else:
                params['current_num'] = self.current_num
        if self.dining_num:
            if hasattr(self.dining_num, 'to_alipay_dict'):
                params['dining_num'] = self.dining_num.to_alipay_dict()
            else:
                params['dining_num'] = self.dining_num
        if self.queue_num:
            if hasattr(self.queue_num, 'to_alipay_dict'):
                params['queue_num'] = self.queue_num.to_alipay_dict()
            else:
                params['queue_num'] = self.queue_num
        if self.still_wait_time:
            if hasattr(self.still_wait_time, 'to_alipay_dict'):
                params['still_wait_time'] = self.still_wait_time.to_alipay_dict()
            else:
                params['still_wait_time'] = self.still_wait_time
        if self.table_type:
            if hasattr(self.table_type, 'to_alipay_dict'):
                params['table_type'] = self.table_type.to_alipay_dict()
            else:
                params['table_type'] = self.table_type
        if self.wait_num:
            if hasattr(self.wait_num, 'to_alipay_dict'):
                params['wait_num'] = self.wait_num.to_alipay_dict()
            else:
                params['wait_num'] = self.wait_num
        if self.waiting_time:
            if hasattr(self.waiting_time, 'to_alipay_dict'):
                params['waiting_time'] = self.waiting_time.to_alipay_dict()
            else:
                params['waiting_time'] = self.waiting_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = QueueInfo()
        if 'current_num' in d:
            o.current_num = d['current_num']
        if 'dining_num' in d:
            o.dining_num = d['dining_num']
        if 'queue_num' in d:
            o.queue_num = d['queue_num']
        if 'still_wait_time' in d:
            o.still_wait_time = d['still_wait_time']
        if 'table_type' in d:
            o.table_type = d['table_type']
        if 'wait_num' in d:
            o.wait_num = d['wait_num']
        if 'waiting_time' in d:
            o.waiting_time = d['waiting_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class WidgetDataAuditRejectResult(object):

    def __init__(self):
        self._audit_memo = None
        self._audit_result = None
        self._data_id = None
        self._mini_app_id = None
        self._reject_field_list = None
        self._widget_id = None

    @property
    def audit_memo(self):
        return self._audit_memo

    @audit_memo.setter
    def audit_memo(self, value):
        self._audit_memo = value
    @property
    def audit_result(self):
        return self._audit_result

    @audit_result.setter
    def audit_result(self, value):
        self._audit_result = value
    @property
    def data_id(self):
        return self._data_id

    @data_id.setter
    def data_id(self, value):
        self._data_id = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def reject_field_list(self):
        return self._reject_field_list

    @reject_field_list.setter
    def reject_field_list(self, value):
        if isinstance(value, list):
            self._reject_field_list = list()
            for i in value:
                self._reject_field_list.append(i)
    @property
    def widget_id(self):
        return self._widget_id

    @widget_id.setter
    def widget_id(self, value):
        self._widget_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.audit_memo:
            if hasattr(self.audit_memo, 'to_alipay_dict'):
                params['audit_memo'] = self.audit_memo.to_alipay_dict()
            else:
                params['audit_memo'] = self.audit_memo
        if self.audit_result:
            if hasattr(self.audit_result, 'to_alipay_dict'):
                params['audit_result'] = self.audit_result.to_alipay_dict()
            else:
                params['audit_result'] = self.audit_result
        if self.data_id:
            if hasattr(self.data_id, 'to_alipay_dict'):
                params['data_id'] = self.data_id.to_alipay_dict()
            else:
                params['data_id'] = self.data_id
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.reject_field_list:
            if isinstance(self.reject_field_list, list):
                for i in range(0, len(self.reject_field_list)):
                    element = self.reject_field_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.reject_field_list[i] = element.to_alipay_dict()
            if hasattr(self.reject_field_list, 'to_alipay_dict'):
                params['reject_field_list'] = self.reject_field_list.to_alipay_dict()
            else:
                params['reject_field_list'] = self.reject_field_list
        if self.widget_id:
            if hasattr(self.widget_id, 'to_alipay_dict'):
                params['widget_id'] = self.widget_id.to_alipay_dict()
            else:
                params['widget_id'] = self.widget_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = WidgetDataAuditRejectResult()
        if 'audit_memo' in d:
            o.audit_memo = d['audit_memo']
        if 'audit_result' in d:
            o.audit_result = d['audit_result']
        if 'data_id' in d:
            o.data_id = d['data_id']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'reject_field_list' in d:
            o.reject_field_list = d['reject_field_list']
        if 'widget_id' in d:
            o.widget_id = d['widget_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.LargeInfiniteCardInfo import LargeInfiniteCardInfo


class AlipayTradeServiceSignResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeServiceSignResponse, self).__init__()
        self._large_infinite_card_info = None

    @property
    def large_infinite_card_info(self):
        return self._large_infinite_card_info

    @large_infinite_card_info.setter
    def large_infinite_card_info(self, value):
        if isinstance(value, LargeInfiniteCardInfo):
            self._large_infinite_card_info = value
        else:
            self._large_infinite_card_info = LargeInfiniteCardInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayTradeServiceSignResponse, self).parse_response_content(response_content)
        if 'large_infinite_card_info' in response:
            self.large_infinite_card_info = response['large_infinite_card_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DatadigitalFincloudFinsaasPutplanPauseModel(object):

    def __init__(self):
        self._operator_id = None
        self._put_plan_id = None
        self._tenant_code = None

    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def put_plan_id(self):
        return self._put_plan_id

    @put_plan_id.setter
    def put_plan_id(self, value):
        self._put_plan_id = value
    @property
    def tenant_code(self):
        return self._tenant_code

    @tenant_code.setter
    def tenant_code(self, value):
        self._tenant_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.put_plan_id:
            if hasattr(self.put_plan_id, 'to_alipay_dict'):
                params['put_plan_id'] = self.put_plan_id.to_alipay_dict()
            else:
                params['put_plan_id'] = self.put_plan_id
        if self.tenant_code:
            if hasattr(self.tenant_code, 'to_alipay_dict'):
                params['tenant_code'] = self.tenant_code.to_alipay_dict()
            else:
                params['tenant_code'] = self.tenant_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DatadigitalFincloudFinsaasPutplanPauseModel()
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'put_plan_id' in d:
            o.put_plan_id = d['put_plan_id']
        if 'tenant_code' in d:
            o.tenant_code = d['tenant_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.DialogueAuditResult import DialogueAuditResult


class AlipayFincoreComplianceRcsmartQtdialogueCheckResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFincoreComplianceRcsmartQtdialogueCheckResponse, self).__init__()
        self._data = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        if isinstance(value, DialogueAuditResult):
            self._data = value
        else:
            self._data = DialogueAuditResult.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayFincoreComplianceRcsmartQtdialogueCheckResponse, self).parse_response_content(response_content)
        if 'data' in response:
            self.data = response['data']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.EcShopInfo import EcShopInfo


class AlipayEbppInvoiceEnterpriseMerchantrelationCreateModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._enterprise_id = None
        self._operator_id = None
        self._shop_info = None
        self._trade_no = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def shop_info(self):
        return self._shop_info

    @shop_info.setter
    def shop_info(self, value):
        if isinstance(value, EcShopInfo):
            self._shop_info = value
        else:
            self._shop_info = EcShopInfo.from_alipay_dict(value)
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.shop_info:
            if hasattr(self.shop_info, 'to_alipay_dict'):
                params['shop_info'] = self.shop_info.to_alipay_dict()
            else:
                params['shop_info'] = self.shop_info
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceEnterpriseMerchantrelationCreateModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'shop_info' in d:
            o.shop_info = d['shop_info']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEcDepartmentInfoQueryModel(object):

    def __init__(self):
        self._department_id = None
        self._enterprise_id = None

    @property
    def department_id(self):
        return self._department_id

    @department_id.setter
    def department_id(self, value):
        self._department_id = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.department_id:
            if hasattr(self.department_id, 'to_alipay_dict'):
                params['department_id'] = self.department_id.to_alipay_dict()
            else:
                params['department_id'] = self.department_id
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEcDepartmentInfoQueryModel()
        if 'department_id' in d:
            o.department_id = d['department_id']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringDishAreaQueryModel(object):

    def __init__(self):
        self._area_id = None
        self._area_name = None
        self._merchant_id = None
        self._shop_id = None
        self._status = None
        self._tab_id = None

    @property
    def area_id(self):
        return self._area_id

    @area_id.setter
    def area_id(self, value):
        self._area_id = value
    @property
    def area_name(self):
        return self._area_name

    @area_name.setter
    def area_name(self, value):
        self._area_name = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tab_id(self):
        return self._tab_id

    @tab_id.setter
    def tab_id(self, value):
        self._tab_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.area_id:
            if hasattr(self.area_id, 'to_alipay_dict'):
                params['area_id'] = self.area_id.to_alipay_dict()
            else:
                params['area_id'] = self.area_id
        if self.area_name:
            if hasattr(self.area_name, 'to_alipay_dict'):
                params['area_name'] = self.area_name.to_alipay_dict()
            else:
                params['area_name'] = self.area_name
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tab_id:
            if hasattr(self.tab_id, 'to_alipay_dict'):
                params['tab_id'] = self.tab_id.to_alipay_dict()
            else:
                params['tab_id'] = self.tab_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishAreaQueryModel()
        if 'area_id' in d:
            o.area_id = d['area_id']
        if 'area_name' in d:
            o.area_name = d['area_name']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'status' in d:
            o.status = d['status']
        if 'tab_id' in d:
            o.tab_id = d['tab_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CarRentalMerchantInfo(object):

    def __init__(self):
        self._brand_name = None
        self._merchant_contact = None
        self._pid = None
        self._smid = None

    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def merchant_contact(self):
        return self._merchant_contact

    @merchant_contact.setter
    def merchant_contact(self, value):
        self._merchant_contact = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.merchant_contact:
            if hasattr(self.merchant_contact, 'to_alipay_dict'):
                params['merchant_contact'] = self.merchant_contact.to_alipay_dict()
            else:
                params['merchant_contact'] = self.merchant_contact
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CarRentalMerchantInfo()
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'merchant_contact' in d:
            o.merchant_contact = d['merchant_contact']
        if 'pid' in d:
            o.pid = d['pid']
        if 'smid' in d:
            o.smid = d['smid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsurancePersonInfo(object):

    def __init__(self):
        self._card_code = None
        self._card_type = None
        self._contact_info = None
        self._name = None

    @property
    def card_code(self):
        return self._card_code

    @card_code.setter
    def card_code(self, value):
        self._card_code = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def contact_info(self):
        return self._contact_info

    @contact_info.setter
    def contact_info(self, value):
        self._contact_info = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_code:
            if hasattr(self.card_code, 'to_alipay_dict'):
                params['card_code'] = self.card_code.to_alipay_dict()
            else:
                params['card_code'] = self.card_code
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.contact_info:
            if hasattr(self.contact_info, 'to_alipay_dict'):
                params['contact_info'] = self.contact_info.to_alipay_dict()
            else:
                params['contact_info'] = self.contact_info
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsurancePersonInfo()
        if 'card_code' in d:
            o.card_code = d['card_code']
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'contact_info' in d:
            o.contact_info = d['contact_info']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPointBudgetGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPointBudgetGetResponse, self).__init__()
        self._budget_amount = None

    @property
    def budget_amount(self):
        return self._budget_amount

    @budget_amount.setter
    def budget_amount(self, value):
        self._budget_amount = value

    def parse_response_content(self, response_content):
        response = super(AlipayPointBudgetGetResponse, self).parse_response_content(response_content)
        if 'budget_amount' in response:
            self.budget_amount = response['budget_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserCertifyOrgIdentityQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserCertifyOrgIdentityQueryResponse, self).__init__()
        self._address = None
        self._business_scope = None
        self._cert_name = None
        self._cert_no = None
        self._cert_type = None
        self._city = None
        self._expiry_date = None
        self._legal_person_real_name = None
        self._province = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def business_scope(self):
        return self._business_scope

    @business_scope.setter
    def business_scope(self, value):
        self._business_scope = value
    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def expiry_date(self):
        return self._expiry_date

    @expiry_date.setter
    def expiry_date(self, value):
        self._expiry_date = value
    @property
    def legal_person_real_name(self):
        return self._legal_person_real_name

    @legal_person_real_name.setter
    def legal_person_real_name(self, value):
        self._legal_person_real_name = value
    @property
    def province(self):
        return self._province

    @province.setter
    def province(self, value):
        self._province = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserCertifyOrgIdentityQueryResponse, self).parse_response_content(response_content)
        if 'address' in response:
            self.address = response['address']
        if 'business_scope' in response:
            self.business_scope = response['business_scope']
        if 'cert_name' in response:
            self.cert_name = response['cert_name']
        if 'cert_no' in response:
            self.cert_no = response['cert_no']
        if 'cert_type' in response:
            self.cert_type = response['cert_type']
        if 'city' in response:
            self.city = response['city']
        if 'expiry_date' in response:
            self.expiry_date = response['expiry_date']
        if 'legal_person_real_name' in response:
            self.legal_person_real_name = response['legal_person_real_name']
        if 'province' in response:
            self.province = response['province']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ContentRiskDetail import ContentRiskDetail
from alipay.aop.api.domain.SubContentRisks import SubContentRisks


class ContentRisks(object):

    def __init__(self):
        self._can_mark = None
        self._file_id = None
        self._file_type = None
        self._origin_file = None
        self._origin_file_id = None
        self._origin_name = None
        self._parent_file_id = None
        self._risks = None
        self._sub_contents = None

    @property
    def can_mark(self):
        return self._can_mark

    @can_mark.setter
    def can_mark(self, value):
        self._can_mark = value
    @property
    def file_id(self):
        return self._file_id

    @file_id.setter
    def file_id(self, value):
        self._file_id = value
    @property
    def file_type(self):
        return self._file_type

    @file_type.setter
    def file_type(self, value):
        self._file_type = value
    @property
    def origin_file(self):
        return self._origin_file

    @origin_file.setter
    def origin_file(self, value):
        self._origin_file = value
    @property
    def origin_file_id(self):
        return self._origin_file_id

    @origin_file_id.setter
    def origin_file_id(self, value):
        self._origin_file_id = value
    @property
    def origin_name(self):
        return self._origin_name

    @origin_name.setter
    def origin_name(self, value):
        self._origin_name = value
    @property
    def parent_file_id(self):
        return self._parent_file_id

    @parent_file_id.setter
    def parent_file_id(self, value):
        self._parent_file_id = value
    @property
    def risks(self):
        return self._risks

    @risks.setter
    def risks(self, value):
        if isinstance(value, list):
            self._risks = list()
            for i in value:
                if isinstance(i, ContentRiskDetail):
                    self._risks.append(i)
                else:
                    self._risks.append(ContentRiskDetail.from_alipay_dict(i))
    @property
    def sub_contents(self):
        return self._sub_contents

    @sub_contents.setter
    def sub_contents(self, value):
        if isinstance(value, list):
            self._sub_contents = list()
            for i in value:
                if isinstance(i, SubContentRisks):
                    self._sub_contents.append(i)
                else:
                    self._sub_contents.append(SubContentRisks.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.can_mark:
            if hasattr(self.can_mark, 'to_alipay_dict'):
                params['can_mark'] = self.can_mark.to_alipay_dict()
            else:
                params['can_mark'] = self.can_mark
        if self.file_id:
            if hasattr(self.file_id, 'to_alipay_dict'):
                params['file_id'] = self.file_id.to_alipay_dict()
            else:
                params['file_id'] = self.file_id
        if self.file_type:
            if hasattr(self.file_type, 'to_alipay_dict'):
                params['file_type'] = self.file_type.to_alipay_dict()
            else:
                params['file_type'] = self.file_type
        if self.origin_file:
            if hasattr(self.origin_file, 'to_alipay_dict'):
                params['origin_file'] = self.origin_file.to_alipay_dict()
            else:
                params['origin_file'] = self.origin_file
        if self.origin_file_id:
            if hasattr(self.origin_file_id, 'to_alipay_dict'):
                params['origin_file_id'] = self.origin_file_id.to_alipay_dict()
            else:
                params['origin_file_id'] = self.origin_file_id
        if self.origin_name:
            if hasattr(self.origin_name, 'to_alipay_dict'):
                params['origin_name'] = self.origin_name.to_alipay_dict()
            else:
                params['origin_name'] = self.origin_name
        if self.parent_file_id:
            if hasattr(self.parent_file_id, 'to_alipay_dict'):
                params['parent_file_id'] = self.parent_file_id.to_alipay_dict()
            else:
                params['parent_file_id'] = self.parent_file_id
        if self.risks:
            if isinstance(self.risks, list):
                for i in range(0, len(self.risks)):
                    element = self.risks[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.risks[i] = element.to_alipay_dict()
            if hasattr(self.risks, 'to_alipay_dict'):
                params['risks'] = self.risks.to_alipay_dict()
            else:
                params['risks'] = self.risks
        if self.sub_contents:
            if isinstance(self.sub_contents, list):
                for i in range(0, len(self.sub_contents)):
                    element = self.sub_contents[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sub_contents[i] = element.to_alipay_dict()
            if hasattr(self.sub_contents, 'to_alipay_dict'):
                params['sub_contents'] = self.sub_contents.to_alipay_dict()
            else:
                params['sub_contents'] = self.sub_contents
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ContentRisks()
        if 'can_mark' in d:
            o.can_mark = d['can_mark']
        if 'file_id' in d:
            o.file_id = d['file_id']
        if 'file_type' in d:
            o.file_type = d['file_type']
        if 'origin_file' in d:
            o.origin_file = d['origin_file']
        if 'origin_file_id' in d:
            o.origin_file_id = d['origin_file_id']
        if 'origin_name' in d:
            o.origin_name = d['origin_name']
        if 'parent_file_id' in d:
            o.parent_file_id = d['parent_file_id']
        if 'risks' in d:
            o.risks = d['risks']
        if 'sub_contents' in d:
            o.sub_contents = d['sub_contents']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechBlockchainFinanceTruspleLoanscenedatapushSubmitModel(object):

    def __init__(self):
        self._currency = None
        self._loan_amount = None
        self._login_id = None
        self._memo = None
        self._out_biz_id = None
        self._receiver_account_no = None
        self._receiver_bank_code = None
        self._receiver_name = None
        self._request_id = None

    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def loan_amount(self):
        return self._loan_amount

    @loan_amount.setter
    def loan_amount(self, value):
        self._loan_amount = value
    @property
    def login_id(self):
        return self._login_id

    @login_id.setter
    def login_id(self, value):
        self._login_id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def out_biz_id(self):
        return self._out_biz_id

    @out_biz_id.setter
    def out_biz_id(self, value):
        self._out_biz_id = value
    @property
    def receiver_account_no(self):
        return self._receiver_account_no

    @receiver_account_no.setter
    def receiver_account_no(self, value):
        self._receiver_account_no = value
    @property
    def receiver_bank_code(self):
        return self._receiver_bank_code

    @receiver_bank_code.setter
    def receiver_bank_code(self, value):
        self._receiver_bank_code = value
    @property
    def receiver_name(self):
        return self._receiver_name

    @receiver_name.setter
    def receiver_name(self, value):
        self._receiver_name = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.loan_amount:
            if hasattr(self.loan_amount, 'to_alipay_dict'):
                params['loan_amount'] = self.loan_amount.to_alipay_dict()
            else:
                params['loan_amount'] = self.loan_amount
        if self.login_id:
            if hasattr(self.login_id, 'to_alipay_dict'):
                params['login_id'] = self.login_id.to_alipay_dict()
            else:
                params['login_id'] = self.login_id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.out_biz_id:
            if hasattr(self.out_biz_id, 'to_alipay_dict'):
                params['out_biz_id'] = self.out_biz_id.to_alipay_dict()
            else:
                params['out_biz_id'] = self.out_biz_id
        if self.receiver_account_no:
            if hasattr(self.receiver_account_no, 'to_alipay_dict'):
                params['receiver_account_no'] = self.receiver_account_no.to_alipay_dict()
            else:
                params['receiver_account_no'] = self.receiver_account_no
        if self.receiver_bank_code:
            if hasattr(self.receiver_bank_code, 'to_alipay_dict'):
                params['receiver_bank_code'] = self.receiver_bank_code.to_alipay_dict()
            else:
                params['receiver_bank_code'] = self.receiver_bank_code
        if self.receiver_name:
            if hasattr(self.receiver_name, 'to_alipay_dict'):
                params['receiver_name'] = self.receiver_name.to_alipay_dict()
            else:
                params['receiver_name'] = self.receiver_name
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainFinanceTruspleLoanscenedatapushSubmitModel()
        if 'currency' in d:
            o.currency = d['currency']
        if 'loan_amount' in d:
            o.loan_amount = d['loan_amount']
        if 'login_id' in d:
            o.login_id = d['login_id']
        if 'memo' in d:
            o.memo = d['memo']
        if 'out_biz_id' in d:
            o.out_biz_id = d['out_biz_id']
        if 'receiver_account_no' in d:
            o.receiver_account_no = d['receiver_account_no']
        if 'receiver_bank_code' in d:
            o.receiver_bank_code = d['receiver_bank_code']
        if 'receiver_name' in d:
            o.receiver_name = d['receiver_name']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ConsumeOutputInfo import ConsumeOutputInfo
from alipay.aop.api.domain.InvoiceOutputInfo import InvoiceOutputInfo
from alipay.aop.api.domain.OcrNormalScanInfo import OcrNormalScanInfo
from alipay.aop.api.domain.OcrPlaneScanInfo import OcrPlaneScanInfo
from alipay.aop.api.domain.OcrTaxiScanInfo import OcrTaxiScanInfo
from alipay.aop.api.domain.OcrTrainScanInfo import OcrTrainScanInfo


class PackageItemOpenInfo(object):

    def __init__(self):
        self._consume_output_info = None
        self._file_download_url = None
        self._file_type = None
        self._invoice_output_info = None
        self._item_source = None
        self._item_sub_type = None
        self._item_type = None
        self._ocr_normal_scan_info = None
        self._ocr_plane_scan_info = None
        self._ocr_taxi_scan_info = None
        self._ocr_train_scan_info = None

    @property
    def consume_output_info(self):
        return self._consume_output_info

    @consume_output_info.setter
    def consume_output_info(self, value):
        if isinstance(value, ConsumeOutputInfo):
            self._consume_output_info = value
        else:
            self._consume_output_info = ConsumeOutputInfo.from_alipay_dict(value)
    @property
    def file_download_url(self):
        return self._file_download_url

    @file_download_url.setter
    def file_download_url(self, value):
        self._file_download_url = value
    @property
    def file_type(self):
        return self._file_type

    @file_type.setter
    def file_type(self, value):
        self._file_type = value
    @property
    def invoice_output_info(self):
        return self._invoice_output_info

    @invoice_output_info.setter
    def invoice_output_info(self, value):
        if isinstance(value, InvoiceOutputInfo):
            self._invoice_output_info = value
        else:
            self._invoice_output_info = InvoiceOutputInfo.from_alipay_dict(value)
    @property
    def item_source(self):
        return self._item_source

    @item_source.setter
    def item_source(self, value):
        self._item_source = value
    @property
    def item_sub_type(self):
        return self._item_sub_type

    @item_sub_type.setter
    def item_sub_type(self, value):
        self._item_sub_type = value
    @property
    def item_type(self):
        return self._item_type

    @item_type.setter
    def item_type(self, value):
        self._item_type = value
    @property
    def ocr_normal_scan_info(self):
        return self._ocr_normal_scan_info

    @ocr_normal_scan_info.setter
    def ocr_normal_scan_info(self, value):
        if isinstance(value, OcrNormalScanInfo):
            self._ocr_normal_scan_info = value
        else:
            self._ocr_normal_scan_info = OcrNormalScanInfo.from_alipay_dict(value)
    @property
    def ocr_plane_scan_info(self):
        return self._ocr_plane_scan_info

    @ocr_plane_scan_info.setter
    def ocr_plane_scan_info(self, value):
        if isinstance(value, OcrPlaneScanInfo):
            self._ocr_plane_scan_info = value
        else:
            self._ocr_plane_scan_info = OcrPlaneScanInfo.from_alipay_dict(value)
    @property
    def ocr_taxi_scan_info(self):
        return self._ocr_taxi_scan_info

    @ocr_taxi_scan_info.setter
    def ocr_taxi_scan_info(self, value):
        if isinstance(value, OcrTaxiScanInfo):
            self._ocr_taxi_scan_info = value
        else:
            self._ocr_taxi_scan_info = OcrTaxiScanInfo.from_alipay_dict(value)
    @property
    def ocr_train_scan_info(self):
        return self._ocr_train_scan_info

    @ocr_train_scan_info.setter
    def ocr_train_scan_info(self, value):
        if isinstance(value, OcrTrainScanInfo):
            self._ocr_train_scan_info = value
        else:
            self._ocr_train_scan_info = OcrTrainScanInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.consume_output_info:
            if hasattr(self.consume_output_info, 'to_alipay_dict'):
                params['consume_output_info'] = self.consume_output_info.to_alipay_dict()
            else:
                params['consume_output_info'] = self.consume_output_info
        if self.file_download_url:
            if hasattr(self.file_download_url, 'to_alipay_dict'):
                params['file_download_url'] = self.file_download_url.to_alipay_dict()
            else:
                params['file_download_url'] = self.file_download_url
        if self.file_type:
            if hasattr(self.file_type, 'to_alipay_dict'):
                params['file_type'] = self.file_type.to_alipay_dict()
            else:
                params['file_type'] = self.file_type
        if self.invoice_output_info:
            if hasattr(self.invoice_output_info, 'to_alipay_dict'):
                params['invoice_output_info'] = self.invoice_output_info.to_alipay_dict()
            else:
                params['invoice_output_info'] = self.invoice_output_info
        if self.item_source:
            if hasattr(self.item_source, 'to_alipay_dict'):
                params['item_source'] = self.item_source.to_alipay_dict()
            else:
                params['item_source'] = self.item_source
        if self.item_sub_type:
            if hasattr(self.item_sub_type, 'to_alipay_dict'):
                params['item_sub_type'] = self.item_sub_type.to_alipay_dict()
            else:
                params['item_sub_type'] = self.item_sub_type
        if self.item_type:
            if hasattr(self.item_type, 'to_alipay_dict'):
                params['item_type'] = self.item_type.to_alipay_dict()
            else:
                params['item_type'] = self.item_type
        if self.ocr_normal_scan_info:
            if hasattr(self.ocr_normal_scan_info, 'to_alipay_dict'):
                params['ocr_normal_scan_info'] = self.ocr_normal_scan_info.to_alipay_dict()
            else:
                params['ocr_normal_scan_info'] = self.ocr_normal_scan_info
        if self.ocr_plane_scan_info:
            if hasattr(self.ocr_plane_scan_info, 'to_alipay_dict'):
                params['ocr_plane_scan_info'] = self.ocr_plane_scan_info.to_alipay_dict()
            else:
                params['ocr_plane_scan_info'] = self.ocr_plane_scan_info
        if self.ocr_taxi_scan_info:
            if hasattr(self.ocr_taxi_scan_info, 'to_alipay_dict'):
                params['ocr_taxi_scan_info'] = self.ocr_taxi_scan_info.to_alipay_dict()
            else:
                params['ocr_taxi_scan_info'] = self.ocr_taxi_scan_info
        if self.ocr_train_scan_info:
            if hasattr(self.ocr_train_scan_info, 'to_alipay_dict'):
                params['ocr_train_scan_info'] = self.ocr_train_scan_info.to_alipay_dict()
            else:
                params['ocr_train_scan_info'] = self.ocr_train_scan_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PackageItemOpenInfo()
        if 'consume_output_info' in d:
            o.consume_output_info = d['consume_output_info']
        if 'file_download_url' in d:
            o.file_download_url = d['file_download_url']
        if 'file_type' in d:
            o.file_type = d['file_type']
        if 'invoice_output_info' in d:
            o.invoice_output_info = d['invoice_output_info']
        if 'item_source' in d:
            o.item_source = d['item_source']
        if 'item_sub_type' in d:
            o.item_sub_type = d['item_sub_type']
        if 'item_type' in d:
            o.item_type = d['item_type']
        if 'ocr_normal_scan_info' in d:
            o.ocr_normal_scan_info = d['ocr_normal_scan_info']
        if 'ocr_plane_scan_info' in d:
            o.ocr_plane_scan_info = d['ocr_plane_scan_info']
        if 'ocr_taxi_scan_info' in d:
            o.ocr_taxi_scan_info = d['ocr_taxi_scan_info']
        if 'ocr_train_scan_info' in d:
            o.ocr_train_scan_info = d['ocr_train_scan_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SimpleMockModel(object):

    def __init__(self):
        self._count_items = None
        self._happen_time = None
        self._price_num = None
        self._right = None
        self._trade_no = None

    @property
    def count_items(self):
        return self._count_items

    @count_items.setter
    def count_items(self, value):
        self._count_items = value
    @property
    def happen_time(self):
        return self._happen_time

    @happen_time.setter
    def happen_time(self, value):
        self._happen_time = value
    @property
    def price_num(self):
        return self._price_num

    @price_num.setter
    def price_num(self, value):
        self._price_num = value
    @property
    def right(self):
        return self._right

    @right.setter
    def right(self, value):
        self._right = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.count_items:
            if hasattr(self.count_items, 'to_alipay_dict'):
                params['count_items'] = self.count_items.to_alipay_dict()
            else:
                params['count_items'] = self.count_items
        if self.happen_time:
            if hasattr(self.happen_time, 'to_alipay_dict'):
                params['happen_time'] = self.happen_time.to_alipay_dict()
            else:
                params['happen_time'] = self.happen_time
        if self.price_num:
            if hasattr(self.price_num, 'to_alipay_dict'):
                params['price_num'] = self.price_num.to_alipay_dict()
            else:
                params['price_num'] = self.price_num
        if self.right:
            if hasattr(self.right, 'to_alipay_dict'):
                params['right'] = self.right.to_alipay_dict()
            else:
                params['right'] = self.right
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SimpleMockModel()
        if 'count_items' in d:
            o.count_items = d['count_items']
        if 'happen_time' in d:
            o.happen_time = d['happen_time']
        if 'price_num' in d:
            o.price_num = d['price_num']
        if 'right' in d:
            o.right = d['right']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceSportsGreenenergyDepositModel(object):

    def __init__(self):
        self._open_id = None
        self._order_status = None
        self._out_order_id = None
        self._total_amount = None
        self._trade_no = None
        self._trade_partner_id = None
        self._user_id = None

    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def out_order_id(self):
        return self._out_order_id

    @out_order_id.setter
    def out_order_id(self, value):
        self._out_order_id = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def trade_partner_id(self):
        return self._trade_partner_id

    @trade_partner_id.setter
    def trade_partner_id(self, value):
        self._trade_partner_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.out_order_id:
            if hasattr(self.out_order_id, 'to_alipay_dict'):
                params['out_order_id'] = self.out_order_id.to_alipay_dict()
            else:
                params['out_order_id'] = self.out_order_id
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.trade_partner_id:
            if hasattr(self.trade_partner_id, 'to_alipay_dict'):
                params['trade_partner_id'] = self.trade_partner_id.to_alipay_dict()
            else:
                params['trade_partner_id'] = self.trade_partner_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceSportsGreenenergyDepositModel()
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'out_order_id' in d:
            o.out_order_id = d['out_order_id']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'trade_partner_id' in d:
            o.trade_partner_id = d['trade_partner_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BailAuthOrderDTO(object):

    def __init__(self):
        self._agreement_no = None
        self._amount = None
        self._auth_no = None
        self._bail_status = None
        self._fund_entrust_type = None
        self._gmt_create = None
        self._gmt_modified = None
        self._open_id = None
        self._order_title = None
        self._partner_open_id = None
        self._partner_user_id = None
        self._product_code = None
        self._scene_code = None
        self._scene_desc = None
        self._user_id = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def auth_no(self):
        return self._auth_no

    @auth_no.setter
    def auth_no(self, value):
        self._auth_no = value
    @property
    def bail_status(self):
        return self._bail_status

    @bail_status.setter
    def bail_status(self, value):
        self._bail_status = value
    @property
    def fund_entrust_type(self):
        return self._fund_entrust_type

    @fund_entrust_type.setter
    def fund_entrust_type(self, value):
        self._fund_entrust_type = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def order_title(self):
        return self._order_title

    @order_title.setter
    def order_title(self, value):
        self._order_title = value
    @property
    def partner_open_id(self):
        return self._partner_open_id

    @partner_open_id.setter
    def partner_open_id(self, value):
        self._partner_open_id = value
    @property
    def partner_user_id(self):
        return self._partner_user_id

    @partner_user_id.setter
    def partner_user_id(self, value):
        self._partner_user_id = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def scene_desc(self):
        return self._scene_desc

    @scene_desc.setter
    def scene_desc(self, value):
        self._scene_desc = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.auth_no:
            if hasattr(self.auth_no, 'to_alipay_dict'):
                params['auth_no'] = self.auth_no.to_alipay_dict()
            else:
                params['auth_no'] = self.auth_no
        if self.bail_status:
            if hasattr(self.bail_status, 'to_alipay_dict'):
                params['bail_status'] = self.bail_status.to_alipay_dict()
            else:
                params['bail_status'] = self.bail_status
        if self.fund_entrust_type:
            if hasattr(self.fund_entrust_type, 'to_alipay_dict'):
                params['fund_entrust_type'] = self.fund_entrust_type.to_alipay_dict()
            else:
                params['fund_entrust_type'] = self.fund_entrust_type
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.order_title:
            if hasattr(self.order_title, 'to_alipay_dict'):
                params['order_title'] = self.order_title.to_alipay_dict()
            else:
                params['order_title'] = self.order_title
        if self.partner_open_id:
            if hasattr(self.partner_open_id, 'to_alipay_dict'):
                params['partner_open_id'] = self.partner_open_id.to_alipay_dict()
            else:
                params['partner_open_id'] = self.partner_open_id
        if self.partner_user_id:
            if hasattr(self.partner_user_id, 'to_alipay_dict'):
                params['partner_user_id'] = self.partner_user_id.to_alipay_dict()
            else:
                params['partner_user_id'] = self.partner_user_id
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.scene_desc:
            if hasattr(self.scene_desc, 'to_alipay_dict'):
                params['scene_desc'] = self.scene_desc.to_alipay_dict()
            else:
                params['scene_desc'] = self.scene_desc
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BailAuthOrderDTO()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'amount' in d:
            o.amount = d['amount']
        if 'auth_no' in d:
            o.auth_no = d['auth_no']
        if 'bail_status' in d:
            o.bail_status = d['bail_status']
        if 'fund_entrust_type' in d:
            o.fund_entrust_type = d['fund_entrust_type']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'order_title' in d:
            o.order_title = d['order_title']
        if 'partner_open_id' in d:
            o.partner_open_id = d['partner_open_id']
        if 'partner_user_id' in d:
            o.partner_user_id = d['partner_user_id']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'scene_desc' in d:
            o.scene_desc = d['scene_desc']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniCloudFileDeleteModel(object):

    def __init__(self):
        self._cloud_id = None
        self._file_name_list = None
        self._path = None

    @property
    def cloud_id(self):
        return self._cloud_id

    @cloud_id.setter
    def cloud_id(self, value):
        self._cloud_id = value
    @property
    def file_name_list(self):
        return self._file_name_list

    @file_name_list.setter
    def file_name_list(self, value):
        if isinstance(value, list):
            self._file_name_list = list()
            for i in value:
                self._file_name_list.append(i)
    @property
    def path(self):
        return self._path

    @path.setter
    def path(self, value):
        self._path = value


    def to_alipay_dict(self):
        params = dict()
        if self.cloud_id:
            if hasattr(self.cloud_id, 'to_alipay_dict'):
                params['cloud_id'] = self.cloud_id.to_alipay_dict()
            else:
                params['cloud_id'] = self.cloud_id
        if self.file_name_list:
            if isinstance(self.file_name_list, list):
                for i in range(0, len(self.file_name_list)):
                    element = self.file_name_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.file_name_list[i] = element.to_alipay_dict()
            if hasattr(self.file_name_list, 'to_alipay_dict'):
                params['file_name_list'] = self.file_name_list.to_alipay_dict()
            else:
                params['file_name_list'] = self.file_name_list
        if self.path:
            if hasattr(self.path, 'to_alipay_dict'):
                params['path'] = self.path.to_alipay_dict()
            else:
                params['path'] = self.path
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniCloudFileDeleteModel()
        if 'cloud_id' in d:
            o.cloud_id = d['cloud_id']
        if 'file_name_list' in d:
            o.file_name_list = d['file_name_list']
        if 'path' in d:
            o.path = d['path']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CarbonTranDetail import CarbonTranDetail


class CarbonTrans(object):

    def __init__(self):
        self._carbon_value = None
        self._detail_list = None
        self._trans_date = None

    @property
    def carbon_value(self):
        return self._carbon_value

    @carbon_value.setter
    def carbon_value(self, value):
        self._carbon_value = value
    @property
    def detail_list(self):
        return self._detail_list

    @detail_list.setter
    def detail_list(self, value):
        if isinstance(value, list):
            self._detail_list = list()
            for i in value:
                if isinstance(i, CarbonTranDetail):
                    self._detail_list.append(i)
                else:
                    self._detail_list.append(CarbonTranDetail.from_alipay_dict(i))
    @property
    def trans_date(self):
        return self._trans_date

    @trans_date.setter
    def trans_date(self, value):
        self._trans_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.carbon_value:
            if hasattr(self.carbon_value, 'to_alipay_dict'):
                params['carbon_value'] = self.carbon_value.to_alipay_dict()
            else:
                params['carbon_value'] = self.carbon_value
        if self.detail_list:
            if isinstance(self.detail_list, list):
                for i in range(0, len(self.detail_list)):
                    element = self.detail_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.detail_list[i] = element.to_alipay_dict()
            if hasattr(self.detail_list, 'to_alipay_dict'):
                params['detail_list'] = self.detail_list.to_alipay_dict()
            else:
                params['detail_list'] = self.detail_list
        if self.trans_date:
            if hasattr(self.trans_date, 'to_alipay_dict'):
                params['trans_date'] = self.trans_date.to_alipay_dict()
            else:
                params['trans_date'] = self.trans_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CarbonTrans()
        if 'carbon_value' in d:
            o.carbon_value = d['carbon_value']
        if 'detail_list' in d:
            o.detail_list = d['detail_list']
        if 'trans_date' in d:
            o.trans_date = d['trans_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniShopRelationQueryModel(object):

    def __init__(self):
        self._entity_id_list = None
        self._operation = None
        self._page_num = None
        self._page_size = None

    @property
    def entity_id_list(self):
        return self._entity_id_list

    @entity_id_list.setter
    def entity_id_list(self, value):
        if isinstance(value, list):
            self._entity_id_list = list()
            for i in value:
                self._entity_id_list.append(i)
    @property
    def operation(self):
        return self._operation

    @operation.setter
    def operation(self, value):
        self._operation = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value


    def to_alipay_dict(self):
        params = dict()
        if self.entity_id_list:
            if isinstance(self.entity_id_list, list):
                for i in range(0, len(self.entity_id_list)):
                    element = self.entity_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.entity_id_list[i] = element.to_alipay_dict()
            if hasattr(self.entity_id_list, 'to_alipay_dict'):
                params['entity_id_list'] = self.entity_id_list.to_alipay_dict()
            else:
                params['entity_id_list'] = self.entity_id_list
        if self.operation:
            if hasattr(self.operation, 'to_alipay_dict'):
                params['operation'] = self.operation.to_alipay_dict()
            else:
                params['operation'] = self.operation
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniShopRelationQueryModel()
        if 'entity_id_list' in d:
            o.entity_id_list = d['entity_id_list']
        if 'operation' in d:
            o.operation = d['operation']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ExtContext import ExtContext


class HuanxuTradeOrderRefundResponse(AlipayResponse):

    def __init__(self):
        super(HuanxuTradeOrderRefundResponse, self).__init__()
        self._channel = None
        self._ext_context = None
        self._refund_amount = None
        self._refund_id = None
        self._refund_request_no = None
        self._refund_status = None

    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def ext_context(self):
        return self._ext_context

    @ext_context.setter
    def ext_context(self, value):
        if isinstance(value, ExtContext):
            self._ext_context = value
        else:
            self._ext_context = ExtContext.from_alipay_dict(value)
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def refund_id(self):
        return self._refund_id

    @refund_id.setter
    def refund_id(self, value):
        self._refund_id = value
    @property
    def refund_request_no(self):
        return self._refund_request_no

    @refund_request_no.setter
    def refund_request_no(self, value):
        self._refund_request_no = value
    @property
    def refund_status(self):
        return self._refund_status

    @refund_status.setter
    def refund_status(self, value):
        self._refund_status = value

    def parse_response_content(self, response_content):
        response = super(HuanxuTradeOrderRefundResponse, self).parse_response_content(response_content)
        if 'channel' in response:
            self.channel = response['channel']
        if 'ext_context' in response:
            self.ext_context = response['ext_context']
        if 'refund_amount' in response:
            self.refund_amount = response['refund_amount']
        if 'refund_id' in response:
            self.refund_id = response['refund_id']
        if 'refund_request_no' in response:
            self.refund_request_no = response['refund_request_no']
        if 'refund_status' in response:
            self.refund_status = response['refund_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundJointaccountTradeQueryModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._biz_scene = None
        self._member_id = None
        self._member_open_id = None
        self._platform_order_id = None
        self._product_code = None
        self._trade_no = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def member_id(self):
        return self._member_id

    @member_id.setter
    def member_id(self, value):
        self._member_id = value
    @property
    def member_open_id(self):
        return self._member_open_id

    @member_open_id.setter
    def member_open_id(self, value):
        self._member_open_id = value
    @property
    def platform_order_id(self):
        return self._platform_order_id

    @platform_order_id.setter
    def platform_order_id(self, value):
        self._platform_order_id = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.member_id:
            if hasattr(self.member_id, 'to_alipay_dict'):
                params['member_id'] = self.member_id.to_alipay_dict()
            else:
                params['member_id'] = self.member_id
        if self.member_open_id:
            if hasattr(self.member_open_id, 'to_alipay_dict'):
                params['member_open_id'] = self.member_open_id.to_alipay_dict()
            else:
                params['member_open_id'] = self.member_open_id
        if self.platform_order_id:
            if hasattr(self.platform_order_id, 'to_alipay_dict'):
                params['platform_order_id'] = self.platform_order_id.to_alipay_dict()
            else:
                params['platform_order_id'] = self.platform_order_id
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundJointaccountTradeQueryModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'member_id' in d:
            o.member_id = d['member_id']
        if 'member_open_id' in d:
            o.member_open_id = d['member_open_id']
        if 'platform_order_id' in d:
            o.platform_order_id = d['platform_order_id']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ScopeInfo import ScopeInfo
from alipay.aop.api.domain.ScopeInfo import ScopeInfo
from alipay.aop.api.domain.TakeAwayScopeInfo import TakeAwayScopeInfo


class CateringServiceScopeInfo(object):

    def __init__(self):
        self._pick_up_scope_info = None
        self._queue_scope_info = None
        self._take_away_scope_info = None

    @property
    def pick_up_scope_info(self):
        return self._pick_up_scope_info

    @pick_up_scope_info.setter
    def pick_up_scope_info(self, value):
        if isinstance(value, ScopeInfo):
            self._pick_up_scope_info = value
        else:
            self._pick_up_scope_info = ScopeInfo.from_alipay_dict(value)
    @property
    def queue_scope_info(self):
        return self._queue_scope_info

    @queue_scope_info.setter
    def queue_scope_info(self, value):
        if isinstance(value, ScopeInfo):
            self._queue_scope_info = value
        else:
            self._queue_scope_info = ScopeInfo.from_alipay_dict(value)
    @property
    def take_away_scope_info(self):
        return self._take_away_scope_info

    @take_away_scope_info.setter
    def take_away_scope_info(self, value):
        if isinstance(value, list):
            self._take_away_scope_info = list()
            for i in value:
                if isinstance(i, TakeAwayScopeInfo):
                    self._take_away_scope_info.append(i)
                else:
                    self._take_away_scope_info.append(TakeAwayScopeInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.pick_up_scope_info:
            if hasattr(self.pick_up_scope_info, 'to_alipay_dict'):
                params['pick_up_scope_info'] = self.pick_up_scope_info.to_alipay_dict()
            else:
                params['pick_up_scope_info'] = self.pick_up_scope_info
        if self.queue_scope_info:
            if hasattr(self.queue_scope_info, 'to_alipay_dict'):
                params['queue_scope_info'] = self.queue_scope_info.to_alipay_dict()
            else:
                params['queue_scope_info'] = self.queue_scope_info
        if self.take_away_scope_info:
            if isinstance(self.take_away_scope_info, list):
                for i in range(0, len(self.take_away_scope_info)):
                    element = self.take_away_scope_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.take_away_scope_info[i] = element.to_alipay_dict()
            if hasattr(self.take_away_scope_info, 'to_alipay_dict'):
                params['take_away_scope_info'] = self.take_away_scope_info.to_alipay_dict()
            else:
                params['take_away_scope_info'] = self.take_away_scope_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CateringServiceScopeInfo()
        if 'pick_up_scope_info' in d:
            o.pick_up_scope_info = d['pick_up_scope_info']
        if 'queue_scope_info' in d:
            o.queue_scope_info = d['queue_scope_info']
        if 'take_away_scope_info' in d:
            o.take_away_scope_info = d['take_away_scope_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.UserDetailInfo import UserDetailInfo
from alipay.aop.api.domain.VoucherInfoDetail import VoucherInfoDetail


class AlipayBusinessOrderConsultResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBusinessOrderConsultResponse, self).__init__()
        self._buyer_info = None
        self._voucher_list = None

    @property
    def buyer_info(self):
        return self._buyer_info

    @buyer_info.setter
    def buyer_info(self, value):
        if isinstance(value, UserDetailInfo):
            self._buyer_info = value
        else:
            self._buyer_info = UserDetailInfo.from_alipay_dict(value)
    @property
    def voucher_list(self):
        return self._voucher_list

    @voucher_list.setter
    def voucher_list(self, value):
        if isinstance(value, list):
            self._voucher_list = list()
            for i in value:
                if isinstance(i, VoucherInfoDetail):
                    self._voucher_list.append(i)
                else:
                    self._voucher_list.append(VoucherInfoDetail.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayBusinessOrderConsultResponse, self).parse_response_content(response_content)
        if 'buyer_info' in response:
            self.buyer_info = response['buyer_info']
        if 'voucher_list' in response:
            self.voucher_list = response['voucher_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarParkingEnterinfoSyncModel(object):

    def __init__(self):
        self._agreement_query = None
        self._car_color = None
        self._car_number = None
        self._entrance_id = None
        self._free_minutes = None
        self._in_time = None
        self._is_encrypt_car_number = None
        self._isv_url = None
        self._out_serial_no = None
        self._parking_id = None
        self._space_number = None
        self._store_id = None

    @property
    def agreement_query(self):
        return self._agreement_query

    @agreement_query.setter
    def agreement_query(self, value):
        self._agreement_query = value
    @property
    def car_color(self):
        return self._car_color

    @car_color.setter
    def car_color(self, value):
        self._car_color = value
    @property
    def car_number(self):
        return self._car_number

    @car_number.setter
    def car_number(self, value):
        self._car_number = value
    @property
    def entrance_id(self):
        return self._entrance_id

    @entrance_id.setter
    def entrance_id(self, value):
        self._entrance_id = value
    @property
    def free_minutes(self):
        return self._free_minutes

    @free_minutes.setter
    def free_minutes(self, value):
        self._free_minutes = value
    @property
    def in_time(self):
        return self._in_time

    @in_time.setter
    def in_time(self, value):
        self._in_time = value
    @property
    def is_encrypt_car_number(self):
        return self._is_encrypt_car_number

    @is_encrypt_car_number.setter
    def is_encrypt_car_number(self, value):
        self._is_encrypt_car_number = value
    @property
    def isv_url(self):
        return self._isv_url

    @isv_url.setter
    def isv_url(self, value):
        self._isv_url = value
    @property
    def out_serial_no(self):
        return self._out_serial_no

    @out_serial_no.setter
    def out_serial_no(self, value):
        self._out_serial_no = value
    @property
    def parking_id(self):
        return self._parking_id

    @parking_id.setter
    def parking_id(self, value):
        self._parking_id = value
    @property
    def space_number(self):
        return self._space_number

    @space_number.setter
    def space_number(self, value):
        self._space_number = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_query:
            if hasattr(self.agreement_query, 'to_alipay_dict'):
                params['agreement_query'] = self.agreement_query.to_alipay_dict()
            else:
                params['agreement_query'] = self.agreement_query
        if self.car_color:
            if hasattr(self.car_color, 'to_alipay_dict'):
                params['car_color'] = self.car_color.to_alipay_dict()
            else:
                params['car_color'] = self.car_color
        if self.car_number:
            if hasattr(self.car_number, 'to_alipay_dict'):
                params['car_number'] = self.car_number.to_alipay_dict()
            else:
                params['car_number'] = self.car_number
        if self.entrance_id:
            if hasattr(self.entrance_id, 'to_alipay_dict'):
                params['entrance_id'] = self.entrance_id.to_alipay_dict()
            else:
                params['entrance_id'] = self.entrance_id
        if self.free_minutes:
            if hasattr(self.free_minutes, 'to_alipay_dict'):
                params['free_minutes'] = self.free_minutes.to_alipay_dict()
            else:
                params['free_minutes'] = self.free_minutes
        if self.in_time:
            if hasattr(self.in_time, 'to_alipay_dict'):
                params['in_time'] = self.in_time.to_alipay_dict()
            else:
                params['in_time'] = self.in_time
        if self.is_encrypt_car_number:
            if hasattr(self.is_encrypt_car_number, 'to_alipay_dict'):
                params['is_encrypt_car_number'] = self.is_encrypt_car_number.to_alipay_dict()
            else:
                params['is_encrypt_car_number'] = self.is_encrypt_car_number
        if self.isv_url:
            if hasattr(self.isv_url, 'to_alipay_dict'):
                params['isv_url'] = self.isv_url.to_alipay_dict()
            else:
                params['isv_url'] = self.isv_url
        if self.out_serial_no:
            if hasattr(self.out_serial_no, 'to_alipay_dict'):
                params['out_serial_no'] = self.out_serial_no.to_alipay_dict()
            else:
                params['out_serial_no'] = self.out_serial_no
        if self.parking_id:
            if hasattr(self.parking_id, 'to_alipay_dict'):
                params['parking_id'] = self.parking_id.to_alipay_dict()
            else:
                params['parking_id'] = self.parking_id
        if self.space_number:
            if hasattr(self.space_number, 'to_alipay_dict'):
                params['space_number'] = self.space_number.to_alipay_dict()
            else:
                params['space_number'] = self.space_number
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingEnterinfoSyncModel()
        if 'agreement_query' in d:
            o.agreement_query = d['agreement_query']
        if 'car_color' in d:
            o.car_color = d['car_color']
        if 'car_number' in d:
            o.car_number = d['car_number']
        if 'entrance_id' in d:
            o.entrance_id = d['entrance_id']
        if 'free_minutes' in d:
            o.free_minutes = d['free_minutes']
        if 'in_time' in d:
            o.in_time = d['in_time']
        if 'is_encrypt_car_number' in d:
            o.is_encrypt_car_number = d['is_encrypt_car_number']
        if 'isv_url' in d:
            o.isv_url = d['isv_url']
        if 'out_serial_no' in d:
            o.out_serial_no = d['out_serial_no']
        if 'parking_id' in d:
            o.parking_id = d['parking_id']
        if 'space_number' in d:
            o.space_number = d['space_number']
        if 'store_id' in d:
            o.store_id = d['store_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OpenApiProvisioningBundle import OpenApiProvisioningBundle
from alipay.aop.api.domain.OpenApiResponseHeader import OpenApiResponseHeader


class AlipayUserApplepayProvisioningbundleQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserApplepayProvisioningbundleQueryResponse, self).__init__()
        self._pass_state = None
        self._provisioning_bundle = None
        self._response_header = None

    @property
    def pass_state(self):
        return self._pass_state

    @pass_state.setter
    def pass_state(self, value):
        self._pass_state = value
    @property
    def provisioning_bundle(self):
        return self._provisioning_bundle

    @provisioning_bundle.setter
    def provisioning_bundle(self, value):
        if isinstance(value, OpenApiProvisioningBundle):
            self._provisioning_bundle = value
        else:
            self._provisioning_bundle = OpenApiProvisioningBundle.from_alipay_dict(value)
    @property
    def response_header(self):
        return self._response_header

    @response_header.setter
    def response_header(self, value):
        if isinstance(value, OpenApiResponseHeader):
            self._response_header = value
        else:
            self._response_header = OpenApiResponseHeader.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayUserApplepayProvisioningbundleQueryResponse, self).parse_response_content(response_content)
        if 'pass_state' in response:
            self.pass_state = response['pass_state']
        if 'provisioning_bundle' in response:
            self.provisioning_bundle = response['provisioning_bundle']
        if 'response_header' in response:
            self.response_header = response['response_header']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundIndustryOperationQueryModel(object):

    def __init__(self):
        self._operation_id = None
        self._pay_out_request_no = None
        self._refund_out_request_no = None

    @property
    def operation_id(self):
        return self._operation_id

    @operation_id.setter
    def operation_id(self, value):
        self._operation_id = value
    @property
    def pay_out_request_no(self):
        return self._pay_out_request_no

    @pay_out_request_no.setter
    def pay_out_request_no(self, value):
        self._pay_out_request_no = value
    @property
    def refund_out_request_no(self):
        return self._refund_out_request_no

    @refund_out_request_no.setter
    def refund_out_request_no(self, value):
        self._refund_out_request_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.operation_id:
            if hasattr(self.operation_id, 'to_alipay_dict'):
                params['operation_id'] = self.operation_id.to_alipay_dict()
            else:
                params['operation_id'] = self.operation_id
        if self.pay_out_request_no:
            if hasattr(self.pay_out_request_no, 'to_alipay_dict'):
                params['pay_out_request_no'] = self.pay_out_request_no.to_alipay_dict()
            else:
                params['pay_out_request_no'] = self.pay_out_request_no
        if self.refund_out_request_no:
            if hasattr(self.refund_out_request_no, 'to_alipay_dict'):
                params['refund_out_request_no'] = self.refund_out_request_no.to_alipay_dict()
            else:
                params['refund_out_request_no'] = self.refund_out_request_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundIndustryOperationQueryModel()
        if 'operation_id' in d:
            o.operation_id = d['operation_id']
        if 'pay_out_request_no' in d:
            o.pay_out_request_no = d['pay_out_request_no']
        if 'refund_out_request_no' in d:
            o.refund_out_request_no = d['refund_out_request_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ApplyBusinessPropertyDTO import ApplyBusinessPropertyDTO
from alipay.aop.api.domain.ApplyOrderLineDTO import ApplyOrderLineDTO


class AlipayOpenAligroupProductopenApplyModel(object):

    def __init__(self):
        self._business_properties = None
        self._channel_code = None
        self._order_lines = None
        self._out_biz_no = None
        self._out_request_no = None
        self._partner_id = None

    @property
    def business_properties(self):
        return self._business_properties

    @business_properties.setter
    def business_properties(self, value):
        if isinstance(value, ApplyBusinessPropertyDTO):
            self._business_properties = value
        else:
            self._business_properties = ApplyBusinessPropertyDTO.from_alipay_dict(value)
    @property
    def channel_code(self):
        return self._channel_code

    @channel_code.setter
    def channel_code(self, value):
        self._channel_code = value
    @property
    def order_lines(self):
        return self._order_lines

    @order_lines.setter
    def order_lines(self, value):
        if isinstance(value, list):
            self._order_lines = list()
            for i in value:
                if isinstance(i, ApplyOrderLineDTO):
                    self._order_lines.append(i)
                else:
                    self._order_lines.append(ApplyOrderLineDTO.from_alipay_dict(i))
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_properties:
            if hasattr(self.business_properties, 'to_alipay_dict'):
                params['business_properties'] = self.business_properties.to_alipay_dict()
            else:
                params['business_properties'] = self.business_properties
        if self.channel_code:
            if hasattr(self.channel_code, 'to_alipay_dict'):
                params['channel_code'] = self.channel_code.to_alipay_dict()
            else:
                params['channel_code'] = self.channel_code
        if self.order_lines:
            if isinstance(self.order_lines, list):
                for i in range(0, len(self.order_lines)):
                    element = self.order_lines[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.order_lines[i] = element.to_alipay_dict()
            if hasattr(self.order_lines, 'to_alipay_dict'):
                params['order_lines'] = self.order_lines.to_alipay_dict()
            else:
                params['order_lines'] = self.order_lines
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAligroupProductopenApplyModel()
        if 'business_properties' in d:
            o.business_properties = d['business_properties']
        if 'channel_code' in d:
            o.channel_code = d['channel_code']
        if 'order_lines' in d:
            o.order_lines = d['order_lines']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMerchantLiveChannelQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMerchantLiveChannelQueryResponse, self).__init__()
        self._channel_content = None
        self._channel_identity = None
        self._channel_secret = None
        self._channel_type = None

    @property
    def channel_content(self):
        return self._channel_content

    @channel_content.setter
    def channel_content(self, value):
        self._channel_content = value
    @property
    def channel_identity(self):
        return self._channel_identity

    @channel_identity.setter
    def channel_identity(self, value):
        self._channel_identity = value
    @property
    def channel_secret(self):
        return self._channel_secret

    @channel_secret.setter
    def channel_secret(self, value):
        self._channel_secret = value
    @property
    def channel_type(self):
        return self._channel_type

    @channel_type.setter
    def channel_type(self, value):
        self._channel_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayMerchantLiveChannelQueryResponse, self).parse_response_content(response_content)
        if 'channel_content' in response:
            self.channel_content = response['channel_content']
        if 'channel_identity' in response:
            self.channel_identity = response['channel_identity']
        if 'channel_secret' in response:
            self.channel_secret = response['channel_secret']
        if 'channel_type' in response:
            self.channel_type = response['channel_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DatadigitalFincloudFinsaasDesignPagetemplateQueryModel(object):

    def __init__(self):
        self._template_code = None

    @property
    def template_code(self):
        return self._template_code

    @template_code.setter
    def template_code(self, value):
        self._template_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.template_code:
            if hasattr(self.template_code, 'to_alipay_dict'):
                params['template_code'] = self.template_code.to_alipay_dict()
            else:
                params['template_code'] = self.template_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DatadigitalFincloudFinsaasDesignPagetemplateQueryModel()
        if 'template_code' in d:
            o.template_code = d['template_code']
        return o


